@@ -1,17 +1,18 @@
 use Bailador::Request;
 use Bailador::Context;
-use Template::Mojo;
+use Bailador::Template::Mojo;
 
 class Bailador::App {
     has %.routes  = { GET => [], 'POST' => [] };
-    has $.location is rw;
+    my $_location;
     has Bailador::Context  $.context  = Bailador::Context.new;
-    has Template::Mojo     $!template; # type object
+    has Bailador::Template $!renderer = Bailador::Template::Mojo.new;
 
     method request  { $.context.request  }
     method response { $.context.response }
+    method location is rw { return-rw $_location }
     method template(Str $tmpl, @params) {
-        $!template.new(slurp "$!location/views/$tmpl").render(|@params);
+        $!renderer.render(slurp("$_location/views/$tmpl"), @params);
     }
 
     my $current = Bailador::App.new;
@@ -29,7 +30,7 @@ class Bailador::App {
     }
 
     method _find_route($meth, $uri) {
-        for %.routes{$meth}.list -> $r {
+        for $current.routes{$meth}.list -> $r {
             next unless $r;
             if $uri ~~ $r.key {
                 return $r, $/;
@@ -39,6 +40,6 @@ class Bailador::App {
     }
 
     method add_route($meth, Pair $route) {
-        %.routes{$meth}.push: $route;
+        $current.routes{$meth}.push: $route;
     }
 }
