@@ -11,9 +11,10 @@ class Panda::Tester does Pies::Tester {
     method test(Pies::Project $p) {
         indir $!resources.workdir($p), {
             if 't'.IO ~~ :d {
-                my $p6lib = "{cwd}/blib/lib:{cwd}/lib:{%*ENV<PERL6LIB> // ''}";
-                my $c = "env PERL6LIB=$p6lib prove -e perl6 -r t/";
-                shell $c and die $p, "Tests failed";
+                withp6lib {
+                    my $c = "prove -e $*EXECUTABLE_NAME -r t/";
+                    shell $c and die $p, "Tests failed";
+                }
             }
         };
     }
